@@ -14,7 +14,7 @@ use vars qw( @EXPORT_OK %EXPORT_TAGS );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 use vars '$VERSION';
-$VERSION = '1.17';
+$VERSION = '1.22';
 my $CPERL = $^V =~ /c$/ ? 1 : 0;
 
 use vars '@Scalars';
@@ -131,7 +131,7 @@ use vars '@Functions';
     BEGIN
     DESTROY
     END ),
-    # STOP was between 5.5.64 - v5.6.0
+    # STOP was between 5.5.64 - 5.6.0
   ($] >= 5.005064 && $] < 5.006
     ? qw(STOP) : qw(CHECK)),
     # INIT was called RESTART before 5.004_50
@@ -148,7 +148,7 @@ use vars '@Functions';
     bind
     binmode
     bless ),
-  ($] >= 5.009003 && ($] < 5.027007 || $CPERL) ? qw(
+  ($] >= 5.009003 && ($] < 5.027007 || $] >= 5.027008 || $CPERL) ? qw(
     break
   ) : ()), qw(
     caller
@@ -189,6 +189,9 @@ use vars '@Functions';
     exists
     exit
     exp ),
+  ($] >= 5.029 && $CPERL ? qw(
+    extern
+  ) : ()),
   ($] >= 5.015008 ? qw(
     fc
   ) : ()), qw(
@@ -235,7 +238,10 @@ use vars '@Functions';
     index
     int
     import
-    ioctl
+    ioctl ),
+  ($] >= 5.031007 ? qw(
+    isa
+  ) : ()), qw(
     join
     keys
     kill
@@ -264,8 +270,10 @@ use vars '@Functions';
     oct
     open
     opendir
-    ord
+    ord ),
+  ($] >= 5.005061 ? qw(
     our
+  ) : ()), qw(
     pack
     pipe
     pop
@@ -443,6 +451,11 @@ use vars '@Barewords';
     x
     xor
     y
+  ),
+  ($] >= 5.033007 ? qw(
+    try
+    catch
+  ) : ()
 ));
 
 use vars '@TieIOMethods';
@@ -609,7 +622,7 @@ for patches and releases.
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2009 Joshua ben Jore, All rights reserved.
-Copyright 2013, 2015, 2017, 2018 Reini Urban, All rights reserved.
+Copyright 2013, 2015, 2017-2019 Reini Urban, All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either:
